@@ -284,7 +284,7 @@ function systemctl_swift {
             services=$(systemctl | grep openstack-swift- | grep running | awk '{print $1}')
             ;;
         start)
-            enable_swift_storage=$(hiera -c /etc/puppet/hiera.yaml 'enable_swift_storage')
+            enable_swift_storage=$(hiera -c /etc/puppet/hiera.yaml tripleo::profile::base::swift::storage::enable_swift_storage)
             if [[ $enable_swift_storage != "true" ]]; then
                 services=( openstack-swift-proxy )
             fi
@@ -297,3 +297,65 @@ function systemctl_swift {
         manage_systemd_service $action $service
     done
 }
+
+# Special-case OVS for https://bugs.launchpad.net/tripleo/+bug/1635205
+# Update condition and add --notriggerun for +bug/1669714
+function special_case_ovs_upgrade_if_needed {
+    # Always ensure yum has full cache
+    yum makecache || echo "Yum makecache failed. This can cause failure later on."
+    if rpm -qa | grep "^openvswitch-2.5.0-14" || rpm -q --scripts openvswitch | awk '/postuninstall/,/*/' | grep "systemctl.*try-restart" ; then
+        echo "Manual upgrade of openvswitch - ovs-2.5.0-14 or restart in postun detected"
+        rm -rf OVS_UPGRADE
+        mkdir OVS_UPGRADE && pushd OVS_UPGRADE
+        echo "Attempting to downloading latest openvswitch with yumdownloader"
+        yumdownloader --resolve openvswitch
+        for pkg in $(ls -1 *.rpm);  do
+            if rpm -U --test $pkg 2>&1 | grep "already installed" ; then
+                echo "Looks like newer version of $pkg is already installed, skipping"
+            else
+                echo "Updating $pkg with --nopostun --notriggerun"
+                rpm -U --replacepkgs --nopostun --notriggerun $pkg
+            fi
+        done
+        popd
+    else
+        echo "Skipping manual upgrade of openvswitch - no restart in postun detected"
+    fi
+
+}
+
+# update os-net-config before ovs see https://bugs.launchpad.net/tripleo/+bug/1695893
+function update_network() {
+    set +e
+    yum -q -y update os-net-config
+    return_code=$?
+    echo "yum update os-net-config return code: $return_code"
+
+    # Writes any changes caused by alterations to os-net-config and bounces the
+    # interfaces *before* restarting the cluster.
+    os-net-config -c /etc/os-net-config/config.json -v --detailed-exit-codes
+
+    RETVAL=$?
+    if [[ $RETVAL == 2 ]]; then
+        echo "os-net-config: interface configuration files updated successfully"
+    elif [[ $RETVAL != 0 ]]; then
+        echo "ERROR: os-net-config configuration failed"
+        exit $RETVAL
+    fi
+    set -e
+
+    # special case https://bugs.launchpad.net/tripleo/+bug/1635205 +bug/1669714
+    special_case_ovs_upgrade_if_needed
+}
+
+# https://bugs.launchpad.net/tripleo/+bug/1704131 guard against yum update
+# waiting for an existing process until the heat stack time out
+function check_for_yum_lock {
+    if [[ -f /var/run/yum.pid ]] ; then
+        ERR="ERROR existing yum.pid detected - can't continue! Please ensure
+there is no other package update process for the duration of the minor update
+worfklow. Exiting."
+        echo $ERR
+        exit 1
+   fi
+}
